pyvisco.master
==============

.. automodule:: pyvisco.master

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      fit_at_pwr
      fit_pwr
      get_aT
      get_curve
      plot
      plot_shift
      plot_shift_update
      plot_smooth
      pwr_x
      pwr_y
      smooth
   
   

   
   
   

   
   
   



